/common/goal_common.proto

--- v24/common/goal_common.proto    2026-07-21 22:02:14.000000000 +0000
+++ v25/common/goal_common.proto    2026-07-21 22:02:31.000000000 +0000
@@ -29,14 +29,28 @@

 // Lifecycle goal optimization value settings.
 message CustomerLifecycleOptimizationValueSettings {
-  // Value of the lifecycle goal. For example, for retention goals, value is the
-  // incremental conversion value for lapsed customers who are not of high
-  // value.
-  optional double additional_value = 1;
+  // Conversion value adjustment to be applied to (non high lifetime value)
+  // customers in the corresponding lifecycle. For example, for retention goals,
+  // conversion value adjustment is the incremental conversion value for lapsed
+  // customers who are not of high lifetime value.
+  oneof value_adjustment {
+    // Incremental conversion value.
+    double additional_value = 3;

-  // High lifetime value of the lifecycle goal. For example, for customer
-  // acquisition goals, high lifetime value is the incremental conversion value
-  // for lapsed customers who are of high value. High lifetime value should be
-  // greater than value, if set.
-  optional double additional_high_lifetime_value = 2;
+    // Conversion value multiplier.
+    double value_multiplier = 4;
+  }
+
+  // Conversion value adjustment to be applied to customers in the corresponding
+  // lifecycle and identified as high lifetime value. For example, for customer
+  // retention goals, high lifetime value adjustment is the incremental
+  // conversion value for lapsed customers who are of high lifetime value. High
+  // lifetime value should be greater than value, if set.
+  oneof high_lifetime_value_adjustment {
+    // Incremental high lifetime conversion value.
+    double additional_high_lifetime_value = 5;
+
+    // High lifetime conversion value multiplier.
+    double high_lifetime_value_multiplier = 6;
+  }
 }